from test_all_fixers import lib3to2FixerTestCase
from itertools import count

class Test_division(lib3to2FixerTestCase):
    fixer = u"division"

    counter = count(1)
    divisions = [(u"1", u"2"),
                 (u"spam",u"eggs"),
                 (u"lambda a: a(4)", u"my_foot(your_face)"),
                 (u"temp(bob)", u"4"),
                 (u"29.4", u"green()")]

    for top,bottom in divisions:
        exec(u"def test_%d(self):\n    b = \"%s/%s\"\n    a = \"from __future__ import division\\n%s/%s\"\n    self.check(b, a)" % (counter.next(), top, bottom, top, bottom))



from test_all_fixers import lib3to2FixerTestCase

class Test_bytes(lib3to2FixerTestCase):
    fixer = u"bytes"

    def test_bytes_call_1(self):
        b = u"""bytes(x)"""
        a = u"""str(x)"""
        self.check(b, a)

    def test_bytes_call_2(self):
        b = u"""a = bytes(x) + b"florist" """
        a = u"""a = str(x) + "florist" """
        self.check(b, a)

    def test_bytes_call_noargs(self):
        b = u"""bytes()"""
        a = u"""str()"""
        self.check(b, a)

    def test_bytes_call_args_1(self):
        b = u"""bytes(x, y, z)"""
        a = u"""str(x).encode(y, z)"""
        self.check(b, a)

    def test_bytes_call_args_2(self):
        b = u"""bytes(encoding="utf-8", source="dinosaur", errors="dont-care")"""
        a = u"""str("dinosaur").encode("utf-8", "dont-care")"""
        self.check(b, a)

    def test_bytes_literal_1(self):
        b = u'''b"\x41"'''
        a = u'''"\x41"'''
        self.check(b, a)

    def test_bytes_literal_2(self):
        b = u"""b'x'"""
        a = u"""'x'"""
        self.check(b, a)

    def test_bytes_literal_3(self):
        b = u"""BR'''\x13'''"""
        a = u"""R'''\x13'''"""
        self.check(b, a)

    def test_bytes_concatenation(self):
        b = u"""b'bytes' + b'bytes'"""
        a = u"""'bytes' + 'bytes'"""
        self.check(b, a)



from test_all_fixers import lib3to2FixerTestCase

class Test_unittest(lib3to2FixerTestCase):
    fixer = u'unittest'

    def test_imported(self):
        b = u"import unittest"
        a = u"import unittest2"
        self.check(b, a)

    def test_used(self):
        b = u"unittest.AssertStuff(True)"
        a = u"unittest2.AssertStuff(True)"
        self.check(b, a)

    def test_from_import(self):
        b = u"from unittest import *"
        a = u"from unittest2 import *"
        self.check(b, a)

    def test_imported_from(self):
        s = u"from whatever import unittest"
        self.unchanged(s)

    def test_not_base(self):
        s = u"not_unittest.unittest.stuff()"
        self.unchanged(s)
        



from test_all_fixers import lib3to2FixerTestCase

class Test_fullargspec(lib3to2FixerTestCase):

    fixer = u"fullargspec"

    def test_import(self):
        b = u"from inspect import blah, blah, getfullargspec, blah, blah"
        a = u"from inspect import blah, blah, getargspec, blah, blah"
        self.warns(b, a, u"some of the values returned by getfullargspec are not valid in Python 2 and have no equivalent.")

    def test_usage(self):
        b = u"argspec = inspect.getfullargspec(func)"
        a = u"argspec = inspect.getargspec(func)"
        self.warns(b, a, u"some of the values returned by getfullargspec are not valid in Python 2 and have no equivalent.")
